@@ -12,7 +12,7 @@ use base qw( Class::Accessor );
 my @variables = qw(
    dbtype dbname dbuser dbpass dbport dbhost dbencoding
    script_name install_directory script_url
-   custom_lib_path use_plucene indexing_directory enable_page_deletion
+   custom_lib_path use_plucene use_lucy indexing_directory enable_page_deletion
    admin_pass stylesheet_url site_name navbar_on_home_page
    recent_changes_on_home_page random_page_omits_locales
    random_page_omits_categories content_above_navbar_in_html home_name
@@ -78,6 +78,7 @@ sub _init {
                      script_name => "wiki.cgi",
                      install_directory => "/usr/lib/cgi-bin/openguides/",
                      use_plucene => 1,
+                     use_lucy => 0,
                      indexing_directory => "/usr/lib/cgi-bin/openguides/indexes/",
                      enable_page_deletion => 0,
                      moderation_requires_password => 1,
@@ -163,6 +164,7 @@ sub _init {
         script_url => "What URL does the install directory map to?",
         custom_lib_path => "Do you want me to munge a custom lib path into the scripts?  If so, enter it here.  Separate path entries with whitespace.",
         use_plucene => "Do you want to use Plucene for searching? (recommended, but see Changes file before saying yes to this if you are upgrading)",
+        use_lucy => "Do you want to use Lucy for searching? (experimental)",
         indexing_directory => "What directory can I use to store indexes in for searching? ***NOTE*** This directory must exist and be writeable by the user that your script will run as.  See README for more on this.",
         enable_page_deletion => "Do you want to enable page deletion?",
         moderation_requires_password => "Is the admin password required for moderating pages?",
@@ -267,6 +269,8 @@ sub script_url {
 
 =item * use_plucene (default: true)
 
+=item * use_lucy (default: false)
+
 =item * indexing_directory (default: C</usr/lib/cgi-bin/openguides/indexes>)
 
 =item * enable_page_deletion (default: false)
